from setuptools import setup

setup(name='nqviz',
      version='0.0.2',
      description='N Queen Visualizer',
      packages=['nqviz'],
      install_requires=['pygame>=2.0.1'],
      author = 'Jianming Han',
      author_email = 'hjma810@126.com',
      zip_safe=False)